import GL from '@luma.gl/constants';
import { WebGLDevice } from '@luma.gl/webgl';
import { DEPRECATED_FEATURES, DEPRECATED_TO_CLASSIC_FEATURES } from './features';
export function createGLContext(options) {
  const webglDevice = new WebGLDevice(options);
  return webglDevice.gl;
}
export function instrumentGLContext(gl, options) {
  const webglDevice = WebGLDevice.attach(gl);
  return webglDevice.gl;
}
export function resizeGLContext(gl, options) {
  const webglDevice = WebGLDevice.attach(gl);
  webglDevice.canvasContext.resize(options);
}
export function hasFeatures(gl, features) {
  const webglDevice = WebGLDevice.attach(gl);
  const normalizedFeatures = Array.isArray(features) ? features : [features];
  const deviceFeatures = normalizedFeatures.map(feature => classicToDeviceFeature(feature));
  return deviceFeatures.every(feature => webglDevice.features.has(feature));
}

function classicToDeviceFeature(feature) {
  return DEPRECATED_TO_CLASSIC_FEATURES[feature];
}

export function hasFeature(gl, feature) {
  return hasFeatures(gl, feature);
}
export function getFeatures(gl) {
  const webglDevice = WebGLDevice.attach(gl);
  const featureMap = {};

  for (const feature in DEPRECATED_FEATURES) {
    featureMap[feature] = webglDevice.features.has(classicToDeviceFeature(feature));
  }

  return featureMap;
}
export function getContextDebugInfo(gl) {
  const webglDevice = WebGLDevice.attach(gl);
  const info = webglDevice.info;
  return { ...webglDevice.info,
    vendorMasked: webglDevice.info.vendor,
    rendererMasked: webglDevice.info.renderer
  };
}
export function getGLContextInfo(gl) {
  const info = getContextDebugInfo(gl);
  return {
    [GL.UNMASKED_VENDOR_WEBGL]: info.vendor,
    [GL.UNMASKED_RENDERER_WEBGL]: info.renderer,
    [GL.VENDOR]: info.vendorMasked,
    [GL.RENDERER]: info.rendererMasked,
    [GL.VERSION]: info.version
  };
}
export function getContextInfo(gl) {
  return { ...getContextDebugInfo(gl),
    ...getContextLimits(gl),
    info: getGLContextInfo(gl)
  };
}
export function getContextLimits(gl) {
  const webglDevice = WebGLDevice.attach(gl);
  return {
    limits: webglDevice.webglLimits
  };
}
//# sourceMappingURL=context-api.js.map