import GL from '@luma.gl/constants';
import Buffer from './buffer';
import Texture from './texture';
import Framebuffer from './framebuffer';
/**
 * Copies data from a type  or a Texture object into ArrayBuffer object.
 * App can provide targetPixelArray or have it auto allocated by this method
 *  newly allocated by this method unless provided by app.
 * @note Slow requires roundtrip to GPU
 *
 * @param source
 * @param options
 * @returns pixel array,
 */
export declare function readPixelsToArray(source: Framebuffer | Texture, options?: {
    sourceX?: number;
    sourceY?: number;
    sourceFormat?: number;
    sourceAttachment?: number;
    target?: Uint8Array | Uint16Array | Float32Array;
    sourceWidth?: number;
    sourceHeight?: number;
    sourceType?: number;
}): Uint8Array | Uint16Array | Float32Array;
/**
 * Copies data from a Framebuffer or a Texture object into a Buffer object.
 * NOTE: doesn't wait for copy to be complete, it programs GPU to perform a DMA transffer.
 * @param source
 * @param options
 */
export declare function readPixelsToBuffer(source: Framebuffer | Texture, options?: {
    sourceX?: number;
    sourceY?: number;
    sourceFormat?: number;
    target?: Buffer;
    targetByteOffset?: number;
    sourceWidth?: number;
    sourceHeight?: number;
    sourceType?: number;
}): Buffer;
export declare function copyToDataUrl(source: any, options?: {
    sourceAttachment?: number;
    targetMaxHeight?: number;
}): string;
export declare function copyToImage(source: Framebuffer | Texture, options?: {
    sourceAttachment?: number;
    targetImage?: typeof Image;
}): typeof Image;
/**
 * Copy a rectangle from a Framebuffer or Texture object into a texture (at an offset)
 */
export declare function copyToTexture(source: Framebuffer | Texture, target: Texture | GL, options?: {
    sourceX?: number;
    sourceY?: number;
    targetX?: number;
    targetY?: number;
    targetZ?: number;
    targetMipmaplevel?: number;
    targetInternalFormat?: number;
    width?: number;
    height?: number;
}): Texture;
/**
 * Copies a rectangle of pixels between Framebuffer or Texture objects
 * @note NOTE: WEBLG2 only
 * @param source
 * @param target
 * @param options
 */
export declare function blit(source: any, target: any, options: {
    sourceAttachment?: number;
    sourceX0?: number;
    sourceY0?: number;
    sourceX1?: number;
    sourceY1?: number;
    targetX0?: number;
    targetY0?: number;
    targetX1?: number;
    targetY1?: number;
    color?: boolean;
    depth?: boolean;
    stencil?: boolean;
    mask?: number;
    filter?: number;
}): void;
//# sourceMappingURL=copy-and-blit.d.ts.map