import { assert } from '@luma.gl/api';
import { isWebGL2, _checkFloat32ColorAttachment } from '@luma.gl/webgl';
export const DEPRECATED_FEATURES = {
  WEBGL2: 'WEBGL2',
  VERTEX_ARRAY_OBJECT: 'VERTEX_ARRAY_OBJECT',
  TIMER_QUERY: 'TIMER_QUERY',
  INSTANCED_RENDERING: 'INSTANCED_RENDERING',
  MULTIPLE_RENDER_TARGETS: 'MULTIPLE_RENDER_TARGETS',
  ELEMENT_INDEX_UINT32: 'ELEMENT_INDEX_UINT32',
  BLEND_EQUATION_MINMAX: 'BLEND_EQUATION_MINMAX',
  FLOAT_BLEND: 'FLOAT_BLEND',
  COLOR_ENCODING_SRGB: 'COLOR_ENCODING_SRGB',
  TEXTURE_DEPTH: 'TEXTURE_DEPTH',
  TEXTURE_FLOAT: 'TEXTURE_FLOAT',
  TEXTURE_HALF_FLOAT: 'TEXTURE_HALF_FLOAT',
  TEXTURE_FILTER_LINEAR_FLOAT: 'TEXTURE_FILTER_LINEAR_FLOAT',
  TEXTURE_FILTER_LINEAR_HALF_FLOAT: 'TEXTURE_FILTER_LINEAR_HALF_FLOAT',
  TEXTURE_FILTER_ANISOTROPIC: 'TEXTURE_FILTER_ANISOTROPIC',
  COLOR_ATTACHMENT_RGBA32F: 'COLOR_ATTACHMENT_RGBA32F',
  COLOR_ATTACHMENT_FLOAT: 'COLOR_ATTACHMENT_FLOAT',
  COLOR_ATTACHMENT_HALF_FLOAT: 'COLOR_ATTACHMENT_HALF_FLOAT',
  GLSL_FRAG_DATA: 'GLSL_FRAG_DATA',
  GLSL_FRAG_DEPTH: 'GLSL_FRAG_DEPTH',
  GLSL_DERIVATIVES: 'GLSL_DERIVATIVES',
  GLSL_TEXTURE_LOD: 'GLSL_TEXTURE_LOD'
};
export const DEPRECATED_TO_CLASSIC_FEATURES = {
  WEBGL2: 'webgl2',
  VERTEX_ARRAY_OBJECT: 'webgl',
  TIMER_QUERY: 'timer-query-webgl',
  INSTANCED_RENDERING: 'instanced-rendering-webgl1',
  MULTIPLE_RENDER_TARGETS: 'multiple-render-targets-webgl1',
  ELEMENT_INDEX_UINT32: 'index-uint32-webgl1',
  BLEND_EQUATION_MINMAX: 'blend-minmax-webgl1',
  FLOAT_BLEND: 'texture-blend-float-webgl1',
  COLOR_ENCODING_SRGB: 'texture-formats-srgb-webgl1',
  TEXTURE_DEPTH: 'texture-formats-depth-webgl1',
  TEXTURE_FLOAT: 'texture-formats-float32-webgl1',
  TEXTURE_HALF_FLOAT: 'texture-formats-float16-webgl1',
  TEXTURE_FILTER_LINEAR_FLOAT: 'texture-filter-linear-float32-webgl',
  TEXTURE_FILTER_LINEAR_HALF_FLOAT: 'texture-filter-linear-float16-webgl',
  TEXTURE_FILTER_ANISOTROPIC: 'texture-filter-anisotropic-webgl',
  COLOR_ATTACHMENT_RGBA32F: 'texture-renderable-rgba32float-webgl',
  COLOR_ATTACHMENT_FLOAT: 'texture-renderable-float32-webgl',
  COLOR_ATTACHMENT_HALF_FLOAT: 'texture-renderable-float16-webgl',
  GLSL_FRAG_DATA: 'glsl-frag-data',
  GLSL_FRAG_DEPTH: 'glsl-frag-depth',
  GLSL_DERIVATIVES: 'glsl-derivatives',
  GLSL_TEXTURE_LOD: 'glsl-texture-lod'
};
export function getWebGLFeatures(gl) {
  gl.getExtension('EXT_color_buffer_float');
  gl.getExtension('WEBGL_color_buffer_float');
  gl.getExtension('EXT_float_blend');
  const features = new Set();

  for (const feature in WEBGL_FEATURES) {
    if (isFeatureSupported(gl, feature)) {
      features.add(feature);
    }
  }

  return features;
}

function isFeatureSupported(gl, cap) {
  const feature = WEBGL_FEATURES[cap];
  assert(feature, cap);
  const [webgl1Feature, webgl2Feature] = feature;
  const featureDefinition = isWebGL2(gl) ? webgl2Feature : webgl1Feature;

  if (cap === DEPRECATED_FEATURES.COLOR_ATTACHMENT_RGBA32F && !isWebGL2(gl)) {
    return _checkFloat32ColorAttachment(gl);
  }

  if (typeof featureDefinition === 'string') {
    return Boolean(gl.getExtension(featureDefinition));
  }

  return featureDefinition;
}

const WEBGL_FEATURES = {
  [DEPRECATED_FEATURES.WEBGL2]: [false, true],
  [DEPRECATED_FEATURES.VERTEX_ARRAY_OBJECT]: ['OES_vertex_array_object', true],
  [DEPRECATED_FEATURES.TIMER_QUERY]: ['EXT_disjoint_timer_query', 'EXT_disjoint_timer_query_webgl2'],
  [DEPRECATED_FEATURES.INSTANCED_RENDERING]: ['ANGLE_instanced_arrays', true],
  [DEPRECATED_FEATURES.MULTIPLE_RENDER_TARGETS]: ['WEBGL_draw_buffers', true],
  [DEPRECATED_FEATURES.ELEMENT_INDEX_UINT32]: ['OES_element_index_uint', true],
  [DEPRECATED_FEATURES.BLEND_EQUATION_MINMAX]: ['EXT_blend_minmax', true],
  [DEPRECATED_FEATURES.FLOAT_BLEND]: ['EXT_float_blend', 'EXT_float_blend'],
  [DEPRECATED_FEATURES.COLOR_ENCODING_SRGB]: ['EXT_sRGB', true],
  [DEPRECATED_FEATURES.TEXTURE_DEPTH]: ['WEBGL_depth_texture', true],
  [DEPRECATED_FEATURES.TEXTURE_FLOAT]: ['OES_texture_float', true],
  [DEPRECATED_FEATURES.TEXTURE_HALF_FLOAT]: ['OES_texture_half_float', true],
  [DEPRECATED_FEATURES.TEXTURE_FILTER_LINEAR_FLOAT]: ['OES_texture_float_linear', 'OES_texture_float_linear'],
  [DEPRECATED_FEATURES.TEXTURE_FILTER_LINEAR_HALF_FLOAT]: ['OES_texture_half_float_linear', 'OES_texture_half_float_linear'],
  [DEPRECATED_FEATURES.TEXTURE_FILTER_ANISOTROPIC]: ['EXT_texture_filter_anisotropic', 'EXT_texture_filter_anisotropic'],
  [DEPRECATED_FEATURES.COLOR_ATTACHMENT_RGBA32F]: [false, 'EXT_color_buffer_float'],
  [DEPRECATED_FEATURES.COLOR_ATTACHMENT_FLOAT]: [false, 'EXT_color_buffer_float'],
  [DEPRECATED_FEATURES.COLOR_ATTACHMENT_HALF_FLOAT]: ['EXT_color_buffer_half_float', 'EXT_color_buffer_half_float'],
  [DEPRECATED_FEATURES.GLSL_FRAG_DATA]: ['WEBGL_draw_buffers', true],
  [DEPRECATED_FEATURES.GLSL_FRAG_DEPTH]: ['EXT_frag_depth', true],
  [DEPRECATED_FEATURES.GLSL_DERIVATIVES]: ['OES_standard_derivatives', true],
  [DEPRECATED_FEATURES.GLSL_TEXTURE_LOD]: ['EXT_shader_texture_lod', true]
};
//# sourceMappingURL=features.js.map