import type { FramebufferProps } from '@luma.gl/api';
import { Device } from '@luma.gl/api';
import GL from '@luma.gl/constants';
import Renderbuffer from './renderbuffer';
import Texture from './texture';
import { WEBGLFramebuffer } from '@luma.gl/webgl';
export declare type TextureAttachment = [Texture, number?, number?];
export declare type Attachment = WebGLTexture | Renderbuffer | TextureAttachment;
/** @deprecated backwards compatibility props */
export declare type ClassicFramebufferProps = FramebufferProps & {
    attachments?: Record<number, Attachment | Renderbuffer>;
    readBuffer?: number;
    drawBuffers?: number[];
    check?: boolean;
    width?: number;
    height?: number;
    color?: boolean;
    depth?: boolean;
    stencil?: boolean;
};
declare type ColorBufferFloatOptions = {
    colorBufferFloat?: boolean;
    colorBufferHalfFloat?: boolean;
};
/** @deprecated Use device.createFramebuffer() */
export default class ClassicFramebuffer extends WEBGLFramebuffer {
    width: any;
    height: any;
    attachments: {};
    readBuffer: GL;
    drawBuffers: GL[];
    ownResources: any[];
    static readonly FRAMEBUFFER_ATTACHMENT_PARAMETERS: GL[];
    /**
     * Check color buffer float support
     * @param options.colorBufferFloat  Whether floating point textures can be rendered and read
     * @param options.colorBufferHalfFloat Whether half float textures can be rendered and read
     */
    static isSupported(gl: WebGLRenderingContext, options: ColorBufferFloatOptions): boolean;
    /**
     * returns the default Classic
     * Creates a Framebuffer object wrapper for the default WebGL framebuffer (target === null)
     */
    static getDefaultFramebuffer(gl: WebGLRenderingContext): ClassicFramebuffer;
    get MAX_COLOR_ATTACHMENTS(): number;
    get MAX_DRAW_BUFFERS(): number;
    constructor(gl: Device | WebGLRenderingContext, props?: ClassicFramebufferProps);
    get color(): import("@luma.gl/webgl").WEBGLTexture;
    get texture(): import("@luma.gl/webgl").WEBGLTexture;
    get depth(): import("@luma.gl/webgl").WEBGLTexture;
    get stencil(): import("@luma.gl/webgl").WEBGLTexture;
    initialize(props: ClassicFramebufferProps): void;
    checkStatus(): this;
    getStatus(): number;
    bind({ target }?: {
        target?: GL;
    }): this;
    unbind({ target }?: {
        target?: GL;
    }): this;
    /** @note Expects framebuffer to be bound */
    _setReadBuffer(readBuffer: number): void;
    /** @note Expects framebuffer to be bound */
    _setDrawBuffers(drawBuffers: number[]): void;
    _createHandle(): WebGLFramebuffer;
    _deleteHandle(): void;
    _bindHandle(handle: any): void;
    update(options: {
        attachments: Record<string, Attachment | Renderbuffer>;
        readBuffer?: number;
        drawBuffers?: any;
        clearAttachments?: boolean;
        resizeAttachments?: boolean;
    }): this;
    /** Attach from a map of attachments */
    attach(attachments: any, { clearAttachments, resizeAttachments }?: {
        clearAttachments?: boolean;
        resizeAttachments?: boolean;
    }): void;
    clear(options?: {
        color?: any;
        depth?: any;
        stencil?: any;
        drawBuffers?: any[];
    }): this;
    blit(opts?: {}): any;
    invalidate(options: {
        attachments: [];
        x?: number;
        y?: number;
        width: number;
        height: number;
    }): this;
    getAttachmentParameter(attachment: any, pname: any, keys: any): number;
    getAttachmentParameters(attachment: GL, keys: any, parameters?: any): {};
    getParameters(keys?: boolean): {};
    show(): this;
    log(logLevel?: number, message?: string): this;
    _unattach(attachment: any): void;
    /**
     * Attempt to provide workable defaults for WebGL2 symbols under WebGL1
     * null means OK to query
     * TODO - move to webgl1 polyfills
     * @param pname
     * @returns
     */
    _getAttachmentParameterFallback(pname: any): 0 | GL.UNSIGNED_INT | GL.LINEAR | 8;
}
export {};
//# sourceMappingURL=framebuffer.d.ts.map