import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import { getProgramBindings } from '@luma.gl/webgl';
export default class ProgramConfiguration {
  constructor(program) {
    _defineProperty(this, "id", void 0);

    _defineProperty(this, "attributeInfos", []);

    _defineProperty(this, "attributeInfosByName", {});

    _defineProperty(this, "attributeInfosByLocation", []);

    _defineProperty(this, "varyingInfos", []);

    _defineProperty(this, "varyingInfosByName", {});

    this.id = program.id;
    Object.seal(this);
    const bindings = getProgramBindings(program.gl2, program.handle);
    this.attributeInfos = bindings.attributes;

    for (const attributeInfo of bindings.attributes) {
      this.attributeInfosByName[attributeInfo.name] = attributeInfo;
      this.attributeInfosByLocation[attributeInfo.location] = attributeInfo;
    }

    for (const varyingInfo of bindings.varyings) {
      this.varyingInfosByName[varyingInfo.name] = varyingInfo;
    }
  }

  getAttributeInfo(locationOrName) {
    const location = Number(locationOrName);

    if (Number.isFinite(location)) {
      return this.attributeInfosByLocation[location];
    }

    return this.attributeInfosByName[locationOrName] || null;
  }

  getAttributeLocation(locationOrName) {
    const attributeInfo = this.getAttributeInfo(locationOrName);
    return attributeInfo ? attributeInfo.location : -1;
  }

  getAttributeAccessor(locationOrName) {
    const attributeInfo = this.getAttributeInfo(locationOrName);
    return attributeInfo ? attributeInfo.accessor : null;
  }

  getVaryingInfo(locationOrName) {
    const location = Number(locationOrName);

    if (Number.isFinite(location)) {
      return this.varyingInfos[location];
    }

    return this.varyingInfosByName[locationOrName] || null;
  }

  getVaryingIndex(locationOrName) {
    const varying = this.getVaryingInfo(locationOrName);
    return varying ? varying.location : -1;
  }

  getVaryingAccessor(locationOrName) {
    const varying = this.getVaryingInfo(locationOrName);
    return varying ? varying.accessor : null;
  }

}
//# sourceMappingURL=program-configuration.js.map