import type { Device, RenderPipelineProps } from '@luma.gl/api';
import { Shader } from '@luma.gl/api';
import ProgramConfiguration from './program-configuration';
import VertexArray from './vertex-array';
import { WEBGLBuffer, WEBGLRenderPipeline, WEBGLFramebuffer } from '@luma.gl/webgl';
export declare type ProgramProps = Omit<RenderPipelineProps, 'vs' | 'fs'> & {
    /** Compiled vertex shader */
    vs?: Shader | string;
    /** Compiled fragment shader */
    fs?: Shader | string;
    hash?: string;
    varyings?: string[];
    bufferMode?: number;
};
export declare type ProgramDrawOptions = {
    logPriority?: number;
    drawMode?: number;
    vertexCount: any;
    offset?: number;
    start?: number;
    end?: number;
    isIndexed?: boolean;
    indexType?: any;
    instanceCount?: number;
    isInstanced?: boolean;
    vertexArray: VertexArray;
    transformFeedback?: any;
    framebuffer?: WEBGLFramebuffer;
    parameters?: {};
    uniforms?: Record<string, any>;
    samplers?: any;
};
/** @deprecated Use device.createRenderPipeline */
export default class Program extends WEBGLRenderPipeline {
    get [Symbol.toStringTag](): string;
    gl: WebGLRenderingContext;
    gl2: WebGL2RenderingContext;
    configuration: ProgramConfiguration;
    hash: string;
    uniforms: Record<string, any>;
    varyings: string[];
    _textureUniforms: Record<string, any>;
    _isCached: boolean;
    _textureIndexCounter: number;
    _uniformCount: number;
    _uniformSetters: Record<string, Function>;
    private _parameters;
    private vertexArray;
    constructor(device: Device | WebGLRenderingContext, props: ProgramProps);
    destroy(options?: {}): void;
    initialize(props: ProgramProps): this;
    setProps(props: any): this;
    /** @note completely overrides base class */
    setAttributes(attributes: Record<string, WEBGLBuffer>): void;
    /**
     * A good thing about the WebGL API is that there are so many ways to draw things ;)
     * This function unifies those ways into a single call using common parameters with sane defaults
     * @note completely overrides base class
     */
    draw(options: ProgramDrawOptions): boolean;
    setUniforms(uniforms?: {}): this;
    _areTexturesRenderable(): boolean;
    _bindTextures(): void;
    _setId(id: any): void;
    _getName(): string;
    _getOptionsFromHandle(handle: any): {};
    _getParameter(pname: any): any;
    _readUniformLocationsFromLinkedProgram(): void;
    getActiveUniforms(uniformIndices: any, pname: any): any;
    getUniformBlockIndex(blockName: any): number;
    getActiveUniformBlockParameter(blockIndex: any, pname: any): any;
    uniformBlockBinding(blockIndex: any, blockBinding: any): void;
}
//# sourceMappingURL=program.d.ts.map