import GL from '@luma.gl/constants';
import { WebGLDevice, WEBGLRenderbuffer } from '@luma.gl/webgl';
export default class Renderbuffer extends WEBGLRenderbuffer {
  static isSupported(gl, options) {
    return WEBGLRenderbuffer.isSupported(gl, options);
  }

  static getSamplesForFormat(gl, options) {
    return gl.getInternalformatParameter(GL.RENDERBUFFER, options.format, GL.SAMPLES);
  }

  constructor(gl, props) {
    super(WebGLDevice.attach(gl), props);
  }

  initialize(props) {
    Object.assign(this.props, props);

    this._initialize(this.props);

    return this;
  }

  _syncHandle(handle) {
    this.gl.bindRenderbuffer(GL.RENDERBUFFER, this.handle);
    Object.assign(this.props, {
      format: this.gl.getRenderbufferParameter(GL.RENDERBUFFER, GL.RENDERBUFFER_INTERNAL_FORMAT),
      width: this.gl.getRenderbufferParameter(GL.RENDERBUFFER, GL.RENDERBUFFER_WIDTH),
      height: this.gl.getRenderbufferParameter(GL.RENDERBUFFER, GL.RENDERBUFFER_HEIGHT),
      samples: this.gl.getRenderbufferParameter(GL.RENDERBUFFER, GL.RENDERBUFFER_SAMPLES)
    });
  }

  _getParameter(pname) {
    this.gl.bindRenderbuffer(GL.RENDERBUFFER, this.handle);
    const value = this.gl.getRenderbufferParameter(GL.RENDERBUFFER, pname);
    return value;
  }

}
//# sourceMappingURL=renderbuffer.js.map