import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import { assert, uid } from '@luma.gl/api';
import GL from '@luma.gl/constants';
import { getShaderInfo } from '@luma.gl/shadertools';
import { WebGLDevice, WEBGLShader } from '@luma.gl/webgl';
import { assertWebGLContext } from '@luma.gl/webgl';
const ERR_SOURCE = 'Shader: GLSL source code must be a JavaScript string';
export class Shader extends WEBGLShader {
  static getTypeName(shaderType) {
    switch (shaderType) {
      case GL.VERTEX_SHADER:
        return 'vertex-shader';

      case GL.FRAGMENT_SHADER:
        return 'fragment-shader';

      default:
        assert(false);
        return 'unknown';
    }
  }

  constructor(gl, props) {
    assertWebGLContext(gl);
    assert(typeof props.source === 'string', ERR_SOURCE);
    super(WebGLDevice.attach(gl), { ...props,
      stage: props.shaderType === GL.VERTEX_SHADER ? 'vertex' : 'fragment'
    });

    _defineProperty(this, "shaderType", void 0);

    _defineProperty(this, "source", void 0);

    this.shaderType = props.shaderType;
    this.source = props.source;
    const shaderName = getShaderInfo(props.source).name;

    if (shaderName) {
      this.id = uid(shaderName);
    }
  }

  initialize(props) {
    this._compile(props.source);

    const shaderName = getShaderInfo(props.source).name;

    if (shaderName) {
      this.id = uid(shaderName);
    }

    return this;
  }

  getParameter(pname) {
    return this.device.gl.getShaderParameter(this.handle, pname);
  }

  toString() {
    return "".concat(Shader.getTypeName(this.shaderType), ":").concat(this.id);
  }

  getName() {
    return getShaderInfo(this.source).name || 'unnamed-shader';
  }

  getSource() {
    return this.device.gl.getShaderSource(this.handle);
  }

  getTranslatedSource() {
    const extension = this.device.gl.getExtension('WEBGL_debug_shaders');
    return extension ? extension.getTranslatedShaderSource(this.handle) : 'No translated source available. WEBGL_debug_shaders not implemented';
  }

  _getOptsFromHandle() {
    return {
      type: this.getParameter(GL.SHADER_TYPE),
      source: this.getSource()
    };
  }

}
export class VertexShader extends Shader {
  constructor(gl, props) {
    super(gl, getShaderProps(props, GL.VERTEX_SHADER));
  }

  _createHandle() {
    return this.device.gl.createShader(GL.VERTEX_SHADER);
  }

}
export class FragmentShader extends Shader {
  constructor(gl, props) {
    super(gl, getShaderProps(props, GL.FRAGMENT_SHADER));
  }

  _createHandle() {
    return this.device.gl.createShader(GL.FRAGMENT_SHADER);
  }

}

function getShaderProps(props, shaderType) {
  if (typeof props === 'string') {
    return {
      source: props,
      shaderType
    };
  }

  return { ...props,
    shaderType
  };
}
//# sourceMappingURL=shader.js.map