import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

let _Symbol$toStringTag;

import { assert, getScratchArray, fillArray } from '@luma.gl/api';
import GL from '@luma.gl/constants';
import { getBrowser } from '@probe.gl/env';
import { WebGLDevice } from '@luma.gl/webgl';
import { assertWebGL2Context, isWebGL2 } from '@luma.gl/webgl';
import { WEBGLVertexArrayObject } from '@luma.gl/webgl';
import Buffer from './buffer';
_Symbol$toStringTag = Symbol.toStringTag;
export default class VertexArrayObject extends WEBGLVertexArrayObject {
  get [_Symbol$toStringTag]() {
    return 'VertexArrayObject';
  }

  static isSupported(gl, options) {
    if (options !== null && options !== void 0 && options.constantAttributeZero) {
      return isWebGL2(gl) || getBrowser() === 'Chrome';
    }

    return true;
  }

  static getDefaultArray(gl) {
    const webglDevice = WebGLDevice.attach(gl);
    webglDevice.defaultVertexArray = webglDevice.defaultVertexArray || new VertexArrayObject(gl, {
      handle: null,
      isDefaultArray: true
    });
    return webglDevice.defaultVertexArray;
  }

  static getMaxAttributes(gl) {
    VertexArrayObject.MAX_ATTRIBUTES = VertexArrayObject.MAX_ATTRIBUTES || gl.getParameter(gl.MAX_VERTEX_ATTRIBS);
    return VertexArrayObject.MAX_ATTRIBUTES;
  }

  static setConstant(gl, location, array) {
    switch (array.constructor) {
      case Float32Array:
        VertexArrayObject._setConstantFloatArray(gl, location, array);

        break;

      case Int32Array:
        VertexArrayObject._setConstantIntArray(assertWebGL2Context(gl), location, array);

        break;

      case Uint32Array:
        VertexArrayObject._setConstantUintArray(assertWebGL2Context(gl), location, array);

        break;

      default:
        assert(false);
    }
  }

  constructor(gl, props) {
    var _props$program;

    super(WebGLDevice.attach(gl), { ...props,
      id: (props === null || props === void 0 ? void 0 : props.id) || (props === null || props === void 0 ? void 0 : (_props$program = props.program) === null || _props$program === void 0 ? void 0 : _props$program.id)
    });

    _defineProperty(this, "buffer", null);

    _defineProperty(this, "bufferValue", null);

    _defineProperty(this, "isDefaultArray", false);

    this.isDefaultArray = (props === null || props === void 0 ? void 0 : props.isDefaultArray) || false;
    Object.seal(this);
  }

  delete() {
    super.delete();

    if (this.buffer) {
      this.buffer.delete();
    }

    return this;
  }

  get MAX_ATTRIBUTES() {
    return VertexArrayObject.getMaxAttributes(this.gl);
  }

  getConstantBuffer(elementCount, value) {
    const constantValue = this._normalizeConstantArrayValue(value);

    const byteLength = constantValue.byteLength * elementCount;
    const length = constantValue.length * elementCount;
    let updateNeeded = !this.buffer;
    this.buffer = this.buffer || new Buffer(this.gl, byteLength);
    updateNeeded = updateNeeded || this.buffer.reallocate(byteLength);
    updateNeeded = updateNeeded || !this._compareConstantArrayValues(constantValue, this.bufferValue);

    if (updateNeeded) {
      const typedArray = getScratchArray(value.constructor, length);
      fillArray({
        target: typedArray,
        source: constantValue,
        start: 0,
        count: length
      });
      this.buffer.subData(typedArray);
      this.bufferValue = value;
    }

    return this.buffer;
  }

  initialize(props) {
    return this.setProps(props);
  }

  setProps(props) {
    return this;
  }

  _normalizeConstantArrayValue(arrayValue) {
    if (Array.isArray(arrayValue)) {
      return new Float32Array(arrayValue);
    }

    return arrayValue;
  }

  _compareConstantArrayValues(v1, v2) {
    if (!v1 || !v2 || v1.length !== v2.length || v1.constructor !== v2.constructor) {
      return false;
    }

    for (let i = 0; i < v1.length; ++i) {
      if (v1[i] !== v2[i]) {
        return false;
      }
    }

    return true;
  }

  static _setConstantFloatArray(gl, location, array) {
    switch (array.length) {
      case 1:
        gl.vertexAttrib1fv(location, array);
        break;

      case 2:
        gl.vertexAttrib2fv(location, array);
        break;

      case 3:
        gl.vertexAttrib3fv(location, array);
        break;

      case 4:
        gl.vertexAttrib4fv(location, array);
        break;

      default:
        assert(false);
    }
  }

  static _setConstantIntArray(gl, location, array) {
    assert(isWebGL2(gl));
    gl.vertexAttribI4iv(location, array);
  }

  static _setConstantUintArray(gl, location, array) {
    assert(isWebGL2(gl));
    gl.vertexAttribI4uiv(location, array);
  }

  _getParameter(pname, {
    location
  }) {
    assert(Number.isFinite(location));
    return this.bind(() => {
      switch (pname) {
        case GL.VERTEX_ATTRIB_ARRAY_POINTER:
          return this.gl.getVertexAttribOffset(location, pname);

        default:
          return this.gl.getVertexAttrib(location, pname);
      }
    });
  }

}

_defineProperty(VertexArrayObject, "MAX_ATTRIBUTES", void 0);
//# sourceMappingURL=vertex-array-object.js.map