import { AttributeBinding } from '@luma.gl/api';
import Accessor from './accessor';
import Program from './program';
import ProgramConfiguration from './program-configuration';
import VertexArrayObject from './vertex-array-object';
import { WEBGLBuffer } from '@luma.gl/webgl';
export declare type VertexArrayProps = {
    id?: string;
    program?: Program;
    configuration?: ProgramConfiguration;
    attributes?: Record<string, any>;
    elements?: any;
    bindOnUse?: boolean;
};
export declare type DrawParams = {
    elementCount: number;
    indexType: Uint16ArrayConstructor | Uint32ArrayConstructor;
    indexOffset: number;
    isIndexed: boolean;
    isInstanced: boolean;
    indexCount: number;
    vertexCount: number;
    instanceCount: number;
};
/** @deprecated Use RenderPipeline (public) and WEBGLVertexArrayObject (internal) */
export default class VertexArray {
    id: string;
    gl: WebGLRenderingContext;
    handle: WebGLVertexArrayObject;
    readonly attributes: object;
    vertexArrayObject: VertexArrayObject;
    accessors: Accessor[];
    configuration: ProgramConfiguration | null;
    elements: any;
    elementsAccessor: any;
    values: any;
    unused: any;
    drawParams: any;
    buffer: any;
    bindOnUse: boolean;
    constructor(gl: WebGLRenderingContext, props?: VertexArrayProps);
    delete(): void;
    initialize(props?: VertexArrayProps): this;
    reset(): this;
    setProps(props: VertexArrayProps): this;
    clearDrawParams(): void;
    getDrawParams(): DrawParams;
    setAttributes(attributes: any): this;
    setElementBuffer(elementBuffer?: WEBGLBuffer | null, accessor?: {}): this;
    setBuffer(locationOrName: number | string, buffer: WEBGLBuffer, appAccessor?: {}): this;
    setConstant(locationOrName: any, arrayValue: any, appAccessor?: {}): this;
    unbindBuffers(): this;
    bindBuffers(): this;
    bindForDraw(vertexCount: any, instanceCount: any, func: any): any;
    _resolveLocationAndAccessor(locationOrName: any, value: any, valueAccessor: any, appAccessor: any): {
        location: number;
        accessor: any;
    };
    _getAttributeInfo(attributeName: string | number): AttributeBinding;
    _getAttributeIndex(locationOrName: number | string): {
        location: number;
        name?: string;
    };
    _setAttribute(locationOrName: number | string, value: WEBGLBuffer): void;
    _setAttribute(locationOrName: number | string, value: [WEBGLBuffer, any]): void;
    _setAttribute(locationOrName: number | string, value: ArrayBuffer | any[]): void;
    _setAttribute(locationOrName: number | string, value: {
        value: WEBGLBuffer;
    }): void;
    _setConstantAttributes(vertexCount: number, instanceCount: number): void;
    _setConstantAttributeZero(constant: any, elementCount: number): void;
    _setConstantAttribute(location: number | string, constant: any): void;
    _updateDrawParams(): DrawParams;
    _updateDrawParamsForLocation(drawParams: DrawParams, location: any): void;
    setElements(elementBuffer?: any, accessor?: {}): this;
}
//# sourceMappingURL=vertex-array.d.ts.map