import type { RenderPipelineParameters, Shader } from '@luma.gl/api';
import { Device, Buffer } from '@luma.gl/api';
import GL from '@luma.gl/constants';
import type { ProgramProps } from '../classic/program';
import { Program, VertexArray, TransformFeedback } from '@luma.gl/gltools';
import ProgramManager from './program-manager';
export declare type ClassicModelProps = Omit<ProgramProps, 'attributes'> & {
    id?: string;
    vs?: Shader | string;
    fs?: Shader | string;
    varyings?: string[];
    bufferMode?: any;
    parameters?: RenderPipelineParameters;
    program?: Program;
    modules?: any[];
    defines?: Record<string, number | boolean>;
    inject?: Record<string, any>;
    transpileToGLSL100?: boolean;
    moduleSettings?: object;
    attributes?: Record<string, Buffer | [Buffer, any]>;
    uniforms?: object;
    geometry?: object;
    vertexCount?: number;
    drawMode?: number;
    isInstanced?: boolean;
    instanceCount?: number;
    programManager?: ProgramManager;
    onBeforeRender?: () => void;
    onAfterRender?: () => void;
    _feedbackBuffers?: object;
    timerQueryEnabled?: boolean;
    isIndexed?: boolean;
    indexType?: any;
    indexOffset?: number;
    vertexArrayInstanced?: boolean;
    /** @deprecated Use isInstanced */
    instanced?: boolean;
};
export declare type ModelDrawOptions = {
    moduleSettings?: any;
    framebuffer?: any;
    uniforms?: any;
    attributes?: any;
    transformFeedback?: any;
    parameters?: any;
    vertexArray?: any;
};
/** @deprecated Use new Model class in `@luma.gl/engine` */
export default class Model {
    readonly device: Device;
    readonly gl: WebGLRenderingContext;
    readonly id: string;
    readonly animated: boolean;
    programManager: ProgramManager;
    vertexCount: number;
    lastLogTime: number;
    props: ClassicModelProps;
    userData: Record<string, any>;
    needsRedraw: boolean;
    attributes: Record<string, any>;
    _attributes: Record<string, any>;
    uniforms: Record<string, any>;
    drawMode: any;
    instanceCount: number;
    pickable: boolean;
    programProps: ProgramProps & {
        program?: Program;
        modules: any;
        inject: any;
        defines: any;
        varyings: any;
        bufferMode: any;
        transpileToGLSL100: any;
    };
    vertexArray: VertexArray;
    program: Program;
    transformFeedback: TransformFeedback | undefined;
    _programDirty: boolean;
    _programManagerState: any;
    _managedProgram: any;
    geometryBuffers: {};
    isInstanced: boolean;
    geometry: {};
    constructor(device: Device | WebGLRenderingContext, props: ClassicModelProps);
    initialize(props: ClassicModelProps): void;
    setProps(props: any): void;
    destroy(): void;
    /** @deprecated Use .destroy() */
    delete(): void;
    getDrawMode(): any;
    getVertexCount(): number;
    getInstanceCount(): number;
    getAttributes(): Record<string, any>;
    getProgram(): Program;
    setProgram(props: any): void;
    getUniforms(): Record<string, any>;
    setDrawMode(drawMode: GL): this;
    setVertexCount(vertexCount: number): this;
    setInstanceCount(instanceCount: number): this;
    setGeometry(geometry: any): this;
    setAttributes(attributes?: {}): this;
    setUniforms(uniforms?: {}): this;
    getModuleUniforms(opts?: any): any;
    updateModuleSettings(opts?: any): this;
    clear(opts: any): this;
    draw(opts?: ModelDrawOptions): boolean;
    transform(opts?: ModelDrawOptions): this;
    render(uniforms?: {}): boolean;
    _setClassicModelProps(props: any): void;
    _checkProgram(): void;
    _deleteGeometryBuffers(): void;
    _setAnimationProps(animationProps: any): void;
    _setFeedbackBuffers(feedbackBuffers?: {}): this;
    _logDrawCallStart(logLevel: number): number;
    _logDrawCallEnd(logLevel: number, vertexArray: any, uniforms: any, framebuffer?: any): void;
}
//# sourceMappingURL=classic-model.d.ts.map