import { Resource } from '@luma.gl/api';
import type { TransformProps, TransformDrawOptions, TransformRunOptions } from './transform';
import Buffer, { BufferProps } from '../classic/buffer';
import TransformFeedback from '../classic/transform-feedback';
import Model from '../engine/classic-model';
declare type BufferBinding = {
    sourceBuffers: Record<string, Buffer | {
        buffer: Buffer;
    }>;
    feedbackBuffers?: Record<string, Buffer | {
        buffer: Buffer;
    }>;
    transformFeedback?: TransformFeedback;
};
export default class BufferTransform {
    gl: WebGL2RenderingContext;
    currentIndex: number;
    feedbackMap: Record<string, string>;
    varyings: string[] | null;
    bindings: BufferBinding[];
    resources: Record<string, Resource<any>>;
    constructor(gl: WebGL2RenderingContext, props?: TransformProps);
    setupResources(opts: {
        model: Model;
    }): void;
    updateModelProps(props?: TransformProps): TransformProps;
    getDrawOptions(opts?: TransformRunOptions): TransformDrawOptions;
    swap(): boolean;
    update(opts?: TransformProps): void;
    getBuffer(varyingName: string): Buffer | null;
    getData(options?: {
        varyingName?: string;
    }): any;
    delete(): void;
    _initialize(props?: TransformProps): void;
    _getFeedbackBuffers(props: TransformProps): Record<string, Buffer>;
    _setupBuffers(props?: TransformProps): void;
    _setupTransformFeedback(binding: BufferBinding, opts: {
        model: Model;
    }): void;
    _updateBindings(opts: TransformProps): void;
    _updateBinding(binding: BufferBinding, opts: any): BufferBinding | {
        sourceBuffers: any;
        feedbackBuffers: any;
    };
    _swapBuffers(opts: any): {
        sourceBuffers: Record<string, Buffer>;
        feedbackBuffers: Record<string, Buffer>;
    };
    _createNewBuffer(name: string, opts: BufferProps): Buffer;
    _getNextIndex(): number;
}
export {};
//# sourceMappingURL=buffer-transform.d.ts.map