import Buffer from '../classic/buffer';
import Texture2D from '../classic/texture-2d';
import Framebuffer from '../classic/framebuffer';
import type { TransformProps, TransformDrawOptions } from './transform';
declare type TextureBinding = {
    sourceBuffers: Record<string, Buffer>;
    sourceTextures: Record<string, Texture2D>;
    targetTexture: Texture2D;
    framebuffer?: Framebuffer;
};
export default class TextureTransform {
    gl: WebGL2RenderingContext;
    id: number;
    currentIndex: number;
    _swapTexture: string | null;
    targetTextureVarying: string | null;
    targetTextureType: string | null;
    samplerTextureMap: Record<string, any> | null;
    bindings: TextureBinding[];
    resources: Record<string, any>;
    hasTargetTexture: boolean;
    hasSourceTextures: boolean;
    ownTexture: Texture2D | null;
    elementIDBuffer: Buffer | null;
    _targetRefTexName: string;
    elementCount: number;
    constructor(gl: WebGL2RenderingContext, props?: TransformProps);
    updateModelProps(props?: TransformProps): TransformProps & {
        vs: any;
        fs: string;
        modules: object[];
        uniforms: any;
        inject: Record<string, string>;
    };
    getDrawOptions(opts?: TransformProps): TransformDrawOptions;
    swap(): boolean;
    update(opts?: {}): void;
    getTargetTexture(): Texture2D;
    getData({ packed }?: {
        packed?: boolean;
    }): any;
    getFramebuffer(): Framebuffer;
    delete(): void;
    _initialize(props?: TransformProps): void;
    _createTargetTexture(props: {
        sourceTextures: Record<string, Texture2D>;
        textureOrReference: string | Texture2D;
    }): Texture2D;
    _setupTextures(props?: TransformProps): void;
    _updateElementIDBuffer(elementCount: number): void;
    _updateBindings(opts: {
        sourceBuffers: Record<string, Buffer>;
        sourceTextures: Record<string, Texture2D>;
        targetTexture: Texture2D;
    }): void;
    _updateBinding(binding: TextureBinding, opts: {
        sourceBuffers?: Record<string, Buffer>;
        sourceTextures: Record<string, Texture2D>;
        targetTexture: Texture2D;
    }): TextureBinding;
    _setSourceTextureParameters(): void;
    _swapTextures(opts: {
        sourceTextures: Record<string, Texture2D>;
        targetTexture: Texture2D;
    }): {
        sourceTextures: Record<string, Texture2D>;
        targetTexture: Texture2D;
    } | null;
    _createNewTexture(refTexture: Texture2D): Texture2D;
    _getNextIndex(): number;
    _processVertexShader(props?: TransformProps): {
        vs: any;
        fs: string;
        modules: object[];
        uniforms: any;
        inject: Record<string, string>;
    };
}
export {};
//# sourceMappingURL=texture-transform.d.ts.map