import { assert } from '@luma.gl/api';
import GL from '@luma.gl/constants';
import Texture2D from '../classic/texture-2d';
import TextureCube from '../classic/texture-cube';
import Texture3D from '../classic/texture-3d';
import Framebuffer from '../classic/framebuffer';
export function cloneTextureFrom(refTexture, overrides) {
  assert(refTexture instanceof Texture2D || refTexture instanceof TextureCube || refTexture instanceof Texture3D);
  const TextureType = refTexture.constructor;
  const {
    gl,
    width,
    height,
    format,
    type,
    dataFormat,
    mipmaps
  } = refTexture;
  const textureOptions = {
    width,
    height,
    format,
    type,
    dataFormat,
    mipmaps,
    ...overrides
  };
  return new TextureType(gl, textureOptions);
}
export function toFramebuffer(texture, props) {
  const {
    gl,
    width,
    height,
    id
  } = texture;
  const framebuffer = new Framebuffer(gl, { ...props,
    id: "framebuffer-for-".concat(id),
    width,
    height,
    attachments: {
      [GL.COLOR_ATTACHMENT0]: texture
    }
  });
  return framebuffer;
}
//# sourceMappingURL=texture-utils.js.map